package sgc.portal.qc.qc0101.web;

import org.springframework.web.bind.annotation.*;
import sgc.portal.base.util.EasyHashMap;
import sgc.portal.qc.qc0101.dto.QC01010001USearch;
import sgc.portal.qc.qc0101.model.QC01010001U;
import sgc.portal.qc.qc0101.model.QC01010002U;
import sgc.portal.qc.qc0101.model.QC01010003U;
import sgc.portal.qc.qc0101.service.QC01010001UService;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

@RestController
@RequestMapping("/qc/qc0101")
public class QC01010001UController {
	
    private final QC01010001UService service;

    public QC01010001UController(QC01010001UService service) {
        this.service = service;
    }

    @PostMapping("/QC01010001U/selectQcStndTreeList")
    public List<EasyHashMap<String, Object>> selectQcStndTreeList(@RequestBody QC01010001USearch search) {
        return service.selectQcStndTreeList(search);
    }
    
    @PostMapping("/QC01010001U/selectQcStndList")
    public List<EasyHashMap<String, Object>> selectQcStndList(@RequestBody QC01010001USearch search) {
        return service.selectQcStndList(search);
    }

    @PostMapping("/QC01010001U/saveQcStnd")
    public Map<String, String> saveQcStnd(@RequestBody QC01010001U qC01010001U) {
    	return service.saveQcStnd(qC01010001U);
    }
    
    
    
    @PostMapping("/QC01010001U/selectQcStndPrcgHisList")
    public List<EasyHashMap<String, Object>> selectQcStndPrcgHisList(@RequestBody QC01010001USearch search) {
        return service.selectQcStndPrcgHisList(search);
    }
    
    @PostMapping("/QC01010001U/saveQcStndPrcg1")
    public Map<String, String> saveQcStndPrcg1(@RequestBody QC01010002U qC01010002U) {
    	return service.saveQcStndPrcg1(qC01010002U);
    }
    
    @PostMapping("/QC01010001U/saveQcStndPrcg2")
    public Map<String, String> saveQcStndPrcg2(@RequestBody QC01010002U qC01010002U) {
    	return service.saveQcStndPrcg2(qC01010002U);
    }
    
    @PostMapping("/QC01010001U/selectQcStndPrcgGudlAflIdList")
    public List<EasyHashMap<String, Object>> selectQcStndPrcgGudlAflIdList(@RequestBody QC01010001USearch search) {
        return service.selectQcStndPrcgGudlAflIdList(search);
    }
    
    @PostMapping("/QC01010001U/selectQcStndPrcgHisFrmtAflIdList")
    public List<EasyHashMap<String, Object>> selectQcStndPrcgHisFrmtAflIdList(@RequestBody QC01010001USearch search) {
        return service.selectQcStndPrcgHisFrmtAflIdList(search);
    }
    
    @PostMapping("/QC01010001U/updateGudlAflId1")
    public Map<String, String> updateGudlAflId1(@RequestBody QC01010002U qC01010002U) {
    	return service.updateGudlAflId1(qC01010002U);
    }
    
    @PostMapping("/QC01010001U/updateGudlAflId2")
    public Map<String, String> updateGudlAflId2(@RequestBody QC01010002U qC01010002U) {
    	return service.updateGudlAflId2(qC01010002U);
    }
    
    @PostMapping("/QC01010001U/updateFrmtAflId1")
    public Map<String, String> updateFrmtAflId1(@RequestBody QC01010002U qC01010002U) {
    	return service.updateFrmtAflId1(qC01010002U);
    }
    
    @PostMapping("/QC01010001U/updateFrmtAflId2")
    public Map<String, String> updateFrmtAflId2(@RequestBody QC01010002U qC01010002U) {
    	return service.updateFrmtAflId2(qC01010002U);
    }
    

    @PostMapping("/QC01010001U/selectQcStndGudlList")
    public List<EasyHashMap<String, Object>> selectQcStndGudlList(@RequestBody QC01010001USearch search) {
        return service.selectQcStndGudlList(search);
    }
    
    @PostMapping("/QC01010001U/saveQcStndGudl1")
    public Map<String, String> saveQcStndGudl1(@RequestBody QC01010003U qC01010003U) {
    	return service.saveQcStndGudl1(qC01010003U);
    }
    
    @PostMapping("/QC01010001U/saveQcStndGudl2")
    public Map<String, String> saveQcStndGudl2(@RequestBody QC01010003U qC01010003U) {
    	return service.saveQcStndGudl2(qC01010003U);
    }
    
    @PostMapping("/QC01010001U/selectQcStndGudlHisList")
    public List<EasyHashMap<String, Object>> selectQcStndGudlHisList(@RequestBody QC01010001USearch search) {
        return service.selectQcStndGudlHisList(search);
    }
    
    @PostMapping("/QC01010001U/selectQcStndGudlGudlRelAflIdList")
    public List<EasyHashMap<String, Object>> selectQcStndGudlGudlRelAflIdList(@RequestBody QC01010001USearch search) {
        return service.selectQcStndGudlGudlRelAflIdList(search);
    }
    
    @PostMapping("/QC01010001U/selectQcStndGudlHisGudlRelAflIdList")
    public List<EasyHashMap<String, Object>> selectQcStndGudlHisGudlRelAflIdList(@RequestBody QC01010001USearch search) {
        return service.selectQcStndGudlHisGudlRelAflIdList(search);
    }
    
    @PostMapping("/QC01010001U/updateGudlRelAflId1")
    public Map<String, String> updateGudlRelAflId1(@RequestBody QC01010003U qC01010003U) {
    	return service.updateGudlRelAflId1(qC01010003U);
    }
    
    @PostMapping("/QC01010001U/updateGudlRelAflId2")
    public Map<String, String> updateGudlRelAflId2(@RequestBody QC01010003U qC01010003U) {
    	return service.updateGudlRelAflId2(qC01010003U);
    }
}